timeseria.operations
====================

.. automodule:: timeseria.operations

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Operation
      ScalarOperation
      SeriesOperation
      
      Min
      Max
      Avg
      MAvg
      WAvg
      Sum
      
      Derivative
      Integral
  
      Diff
      CSum

      Filter      
      Merge
      Select
      
      
      
   
   

   
   
   



